include("plots.jl")

function get_max(coordinates, data)
    max, max_coor = findmax(data)
    return max, coordinates[:, max_coor]
end

function get_metrics(scan::ScanData, params::ScanParameters)
    voltage = scan.waveform
    pressure_trace = voltage * params.calibration_factor

    pressure_pn = calc_pressure_pn(pressure_trace)
    pressure_pp = calc_pressure_pp(pressure_trace)

    isppa = calc_intensity_sppa(pressure_trace, params.medium, params.excitation)
    ispta = calc_intensity_spta(pressure_trace, params.medium, params.excitation)
    mi = calc_mechanical_index(pressure_trace, params.excitation)

    isppa_max =  get_max(scan.coordinates, isppa.val)
    ispta_max = get_max(scan.coordinates, ispta.val)
    mi_max = get_max(scan.coordinates, mi.val)

    return ScanMetric(
        params,
        pressure_trace,
        pressure_pn,
        pressure_pp,
        isppa,
        isppa_max,
        ispta,
        ispta_max,
        mi,
        mi_max,
     )
end

function compute_metrics(scan::ScanData, params::ScanParameters)
    return ScanData(
        scan.version,
        scan.axes,
        scan.scope_info,
        scan.time,
        scan.waveform,
        scan.coordinates,
        get_metrics(scan, params),
    )
end


function calc_intensity_sppa(pressure_trace::PressureArray{N}, medium, excitation) where {N}
    return Metric{ISPPA, N-1}(IntensityMetrics.intensity_sppa(pressure_trace, medium, excitation))
end


function calc_intensity_spta(pressure_trace::PressureArray{N}, medium, excitation) where {N}
    return Metric{ISPTA, N-1}(IntensityMetrics.intensity_spta(pressure_trace, medium, excitation))
end


function calc_mechanical_index(pressure_trace::PressureArray{N}, excitation) where {N}
    return Metric{MI, N-1}(IntensityMetrics.mechanical_index(pressure_trace, excitation))
end


function calc_pressure_pn(pressure_trace::PressureArray{N}) where {N}
    return Metric{PNP, N-1}(IntensityMetrics.pn_pressure(pressure_trace))
end

function calc_pressure_pp(pressure_trace::PressureArray{N}) where {N}
    return Metric{PPP, N-1}(IntensityMetrics.pp_pressure(pressure_trace))
end
